@@ -1,3 +1,4 @@
+import os
 import resource
 
 try:
@@ -13,3 +14,4 @@ except:
     import multiprocessing as mp
 
 mp = mp.get_context('spawn')
+debug = os.environ.get('DEBUG', '') # log pipeline exception
