@@ -1,10 +1,11 @@
 from functools import partial
 from queue import Queue
 from threading import Thread
-from typing import List, Any, Union
+from typing import Any, List, Union
 
 from .pipeline import AsyncPipeline, SyncPipeline
 from .resource import Resources
+from .runtime import debug
 from .stage import Stage
 from .task import Task
 from .utils import get_logger, progressbar
@@ -31,7 +32,7 @@ class System(object):
     A system consists of multiple peer pipelines.
     '''
 
-    def __init__(self, num_pipeline: int = 1, debug=False,
+    def __init__(self, num_pipeline: int = 1,
                  show_progress=True,
                  job_queue_size: int = -1,
                  pipeline_job_queue_size: int = 32,
@@ -40,8 +41,10 @@ class System(object):
         self.num_pipeline = num_pipeline
         self.pipeline_fn = partial(
             AsyncPipeline, job_queue_size=pipeline_job_queue_size)
-        if debug:
-            self.logger.info('Debug mode: one SyncPipeline in single process.')
+        self.debug = 'pipeline' in debug
+        if self.debug:
+            self.logger.info(
+                'Debug mode: one SyncPipeline in a single process.')
             self.num_pipeline = 1
             self.pipeline_fn = SyncPipeline
         self.show_progress = show_progress
@@ -62,7 +65,10 @@ class System(object):
         '''
         Define how to extract final results from output tasks.
         '''
-        raise NotImplementedError
+        results = []
+        for task in results_gen:
+            results.append(task.content)
+        return results
 
     def monit_pipeline(self, pipeline_id):
         pipeline = self.pipelines[pipeline_id]
@@ -70,15 +76,20 @@ class System(object):
             job = self.job_queue.get()
             if job is None:
                 return
-            pipeline.job_queue.put(job.task)
-            pipeline.reset()
-            results_gen = pipeline.wait()
+            if isinstance(pipeline, AsyncPipeline):
+                pipeline.job_queue.put(job.task)
+                pipeline.reset()
+                results_gen = pipeline.wait()
+            elif isinstance(pipeline, SyncPipeline):
+                results_gen = pipeline.run_task(job.task)
             if self.show_progress:
                 results_gen = progressbar(
                     results_gen,
                     desc=' Pipeline-%d(%s)' % (pipeline_id, job.name),
                     total=job.length, position=pipeline_id, leave=False)
             results = self.get_results(results_gen)
+            if isinstance(pipeline, SyncPipeline):
+                pipeline.reset()
             job.finish(results)
             self.result_queue.put(job)
             self.progressbar.update()
@@ -92,8 +103,10 @@ class System(object):
             self.pipelines.append(pipeline)
             self.logger.info('Building pipeline %d: \n\t%s', pipeline_i,
                              '\n\t'.join([repr(s) for s in stages]))
-        self.monitor_threads = [Thread(target=self.monit_pipeline, args=(i,))
-                                for i in range(self.num_pipeline)]
+        if not self.debug:
+            self.monitor_threads = [
+                Thread(target=self.monit_pipeline, args=(i,))
+                for i in range(self.num_pipeline)]
         self.progressbar = None
 
     def start(self):
@@ -102,31 +115,39 @@ class System(object):
             total=self.job_count, desc='Jobs', position=self.num_pipeline)
         for pipeline in self.pipelines:
             pipeline.start()
-        for thread in self.monitor_threads:
-            thread.start()
+        if not self.debug:
+            for thread in self.monitor_threads:
+                thread.start()
 
     def add_job(self, job):
         self.job_queue.put(job)
         self.job_count += 1
         self.progressbar.total = self.job_count
         self.progressbar.refresh()
+        if self.debug:
+            self.job_queue.put(None)
+            self.monit_pipeline(0)
 
     def end(self):
+        self.logger.info('Ending system')
         for pipeline in self.pipelines:
             pipeline.end()
         for pipeline in self.pipelines:
             pipeline.join()
         for _ in range(self.num_pipeline):
             self.job_queue.put(None)
-        for thread in self.monitor_threads:
-            thread.join()
+        if not self.debug:
+            for thread in self.monitor_threads:
+                thread.join()
         self.progressbar.close()
 
     def terminate(self):
+        self.logger.info('Terminating system')
         for pipeline in self.pipelines:
             pipeline.terminate()
-        for thread in self.monitor_threads:
-            thread.terminate()
+        if not self.debug:
+            for thread in self.monitor_threads:
+                thread.terminate()
         self.progressbar.close()
 
     def __repr__(self):
